@@ -8,19 +8,42 @@ from keyword import iskeyword as _iskeyword
 from collections import OrderedDict as _OrderedDict
 import itertools
 import tabulate
-from typing import Union, Sequence as Seq, Optional as Opt
+from typing import Sequence
 
 
-class FullError(Exception): pass
+class FullError(Exception):
+    pass
 
-class EmptyError(Exception): pass
+
+class EmptyError(Exception):
+    pass
 
 
 class IntPool:
     """
     A pool of intergers
+
+    A pool will contain the integers in the range [0, capacity)
+
+    Args:
+        capacity: the capacity (size) of the pool.
+
+    Example
+    ~~~~~~~
+
+        >>> from emlib.containers import IntPool
+        >>> pool = IntPool(10)
+        >>> token = pool.pop()
+        >>> len(pool)
+        9
+        >>> pool.push(token)
+        >>> len(pool)
+        10
+        >>> pool.push(4)
+        ValueError: token 4 already in pool
     """
-    def __init__(self, capacity:int, start=0):
+    def __init__(self, capacity: int):
+        start = 0
         self.capacity = capacity
         self.pool = set(range(start, start+capacity))
         self.tokenrange = (start, start+capacity)
@@ -30,20 +53,15 @@ class IntPool:
             raise EmptyError("This pool is empty")
         return self.pool.pop()
 
-    def push(self, token:int) -> None:
+    def push(self, token: int) -> None:
+        if token in self.pool:
+            raise ValueError(f"token {token} already in pool")
         if len(self.pool) == self.capacity:
             raise FullError()
         if not self.tokenrange[0] <= token < self.tokenrange[1]:
             raise ValueError("This token is not part of the pool")
-        if token in self.pool:
-            raise ValueError(f"token {token} already in pool")
         self.pool.add(token)
 
-    def grow(self, n:int) -> None:
-        maxval = self.tokenrange[1]
-        self.pool.update(range(maxval, maxval+n))
-        self.tokenrange = (self.tokenrange[0], maxval+n)
-
     def __contains__(self, item):
         return item in self.pool
 
@@ -58,11 +76,11 @@ class IntPool:
 
 class RecordList(list):
     """
-    A list of namedtuples or records 
+    A list of namedtuples / dataclasses
 
     Args: 
-        data: A seq of namedtuples or dataclass objects
-            A seq. of tuples or lists is also possible. In that case, fields must be given
+        data: A seq of namedtuples or dataclass objects. A seq. of tuples or lists
+            is also possible. In that case, fields must be given
         fields: a string as passed to namedtuple
         itemname: The name of each row (optional), overrides the name given for the namedtuples
         convert: True, data will be converted to namedtuples if they are not already
@@ -75,17 +93,21 @@ class RecordList(list):
 
         
         # generate a RecordList of measures
-        >>> Measure = _namedtuple("Measure", "tempo timesig")
-        >>> measures = RecordList([Measure(*measure) for measure in (
-        ...     (60, (3,4)),
-        ...     (60, (4,4)),
-        ...     (72, (5,8))
-        ... )])
-
+        >>> from dataclasses import dataclass
+        >>> @dataclass
+        ... class Measure:
+        ...     tempo: int
+        ...     timesig: tuple[int, int]
+        >>> measures = [Measure(tempo, timesig) for tempo, timesig in [(60, (3, 4)), (60, (4, 4)), (72, (5, 8))]]
+        >>> measurelist = RecordList(measures)
+        >>> measurelist.get_column('tempo')
+        [60, 60, 72]
     """
 
-    def __init__(self, data:list, fields:Union[str, Seq[str]]=None, itemname:str=None, 
-                 convert=True):
+    def __init__(self,
+                 data: list,
+                 fields: str | Sequence[str] = '',
+                 itemname=''):
         
         if not data and not fields:
             raise ValueError("data is empty, fields must be given")
@@ -113,14 +135,6 @@ class RecordList(list):
             fieldstup = fields.split() if isinstance(fields, str) else tuple(fields)
             fieldstup = _validate_fields(fieldstup)
 
-            if convert:
-                if not fieldstup:
-                    raise ValueError(
-                        "If convert is True, data should be either a list of namedtuples, or"
-                        "fields should be given"
-                    )
-                T = _namedtuple(self.item_name, fieldstup)
-                data = [T(*row) for row in data]
         list.__init__(self, data)
 
         if data_already_namedtuples:
@@ -150,7 +164,7 @@ class RecordList(list):
             showindex=showindex,
         )
 
-    def __getitem__(self, val) -> Union[tuple, RecordList]:
+    def __getitem__(self, val) -> tuple | RecordList:
         if isinstance(val, int):
             return list.__getitem__(self, val)
         else:
@@ -173,7 +187,7 @@ class RecordList(list):
     #  columns
     # ######################################################
 
-    def get_column(self, column: Union[int, str]) -> list:
+    def get_column(self, column: int | str) -> list:
         """
         Return a column by name or index as a list of values. 
         
@@ -196,7 +210,7 @@ class RecordList(list):
             raise TypeError("column should be a label (str), or an index (int)")
         return [item[index] for item in self]
 
-    def add_column(self, name:str, data, itemname:str=None, missing=None) -> RecordList:
+    def add_column(self, name: str, data, itemname: str = '', missing=None) -> RecordList:
         """
         Return a new RecordList with the added data as a column
 
@@ -298,7 +312,7 @@ class RecordList(list):
         self.sort(key=lambda item: getattr(item, column))
 
     @classmethod
-    def from_csv(cls, csvfile:str) -> RecordList:
+    def from_csv(cls, csvfile: str) -> RecordList:
         """
         Create a new RecordList with the data in csvfile
 
@@ -308,12 +322,11 @@ class RecordList(list):
         rows = readcsv(csvfile)
         return cls(rows)
 
-    def to_csv(self, outfile:str) -> None:
+    def to_csv(self, outfile: str) -> None:
         """
         Write the data in this RecordList as a csv file
         """
         from .csvtools import writecsv
-
         writecsv(self, outfile, column_names=self.columns)
 
     @classmethod
@@ -335,7 +348,6 @@ class RecordList(list):
         """
         try:
             import pandas
-
             return pandas.DataFrame(list(self), columns=self.columns)
         except ImportError:
             raise ImportError("pandas is needed to export to pandas.DataFrame!")
@@ -372,88 +384,4 @@ def _validate_fields(field_names: list[str]) -> list[str]:
         ):
             names[i] = "field%d" % i
         seen.add(name)
-    return names
-
-
-class ClassDict(object):
-    """
-    An ordered dictionary with class-like access and lazy-evaluated definitions
-
-    Use normal keyword definitions to assign values, or a lambda accepting "self"
-    to delay evaluation when a value depends on a previous definition (lambdas can 
-    depend on lambdas also, see example --watch out for mutually dependign definitions!)
-
-    initdict: a dictionary to be read first (optional)
-
-    Examples
-    ~~~~~~~~
-
-    .. code::
-
-        >>> config = ClassDict(
-        ...     key1=10,
-        ...     key2=20,
-        ...     key3=lambda self:self.key1+1
-        ...     key4=lambda self:self.key3*2   # 2nd-order lambda
-        ... )
-        >>> # now you can access members like variables:
-        >>> print(config.key1 + config.key3)
-        21
-    """
-    
-    def __init__(self, **kws):
-        isdelayed = lambda obj: callable(obj)
-        ident = 0
-        kws2 = _OrderedDict()
-        for k, v in kws.items():
-            if not isdelayed(v):
-                kws2[k] = v
-        self.__dict__.update(kws2)
-        kws3 = {}
-        delayed_defs = kws
-        maxiterations = 10
-        new_delayed_defs = None
-        for i in range(maxiterations):
-            new_delayed_defs = {}
-            for k, v in delayed_defs.items():
-                if isdelayed(v):
-                    try:
-                        v = v(self)
-                        kws3[k] = v
-                        self.__dict__[k] = v
-                    except AttributeError:
-                        new_delayed_defs[k] = v
-            if not new_delayed_defs:
-                break
-            delayed_defs = new_delayed_defs
-        if new_delayed_defs:
-            raise ValueError("too many delayed definitions!")
-        kws2.update(kws3)
-        d = dict((k, v) for k, v in kws2.items() if not k.startswith("_"))
-        self.__dict__.update(kws3)
-        self._dict = _OrderedDict()
-        self._dict.update(d)
-        self._ident = ident
-        self._identstr = " " * ident
-
-    def __getitem__(self, item):
-        return getattr(self, item)
-
-    def __setitem__(self, item, value):
-        setattr(self, item, value)
-
-    def get(self, attr, default=None):
-        out0 = self.__dict__.get(attr)
-        out1 = self._dict.get(attr)
-        return out0 if out0 is not None else (out1 if out1 is not None else default)
-
-    def __iter__(self):
-        d = dict((k, v) for k, v in self.__dict__.items() if not k.startswith("_"))
-        return d.items()
-
-    def __repr__(self):
-        out = ["{"]
-        for attr, value in self:
-            out.append("%s%s: %s" % (self._identstr, attr, str(value)))
-        out.append("}")
-        return "\n".join(out)
+    return names
\ No newline at end of file
